==> jboss-wfk-2.4.0-snowdrop-src.zip: jboss-wfk-2.4.0/src/snowdrop-3.0.2.Final-redhat-1/vfs/src/main/java/org/jboss/spring/vfs/context/DelegatingContextLoaderListener.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2011, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.spring.vfs.context;

import javax.servlet.ServletContext;

import org.springframework.context.ApplicationContextException;
import org.springframework.web.context.ContextLoader;
import org.springframework.web.context.ContextLoaderListener;

/**
 * @author Marius Bogoevici
 */
public class DelegatingContextLoaderListener extends ContextLoaderListener {

    @Override
    protected ContextLoader createContextLoader() {
        if (!ContextClassUtil.isJBossAS5orHigher()) {
            return super.createContextLoader();
        } else {
            return new VFSContextLoader();
        }
    }

    private static class VFSContextLoader extends ContextLoader {

        @Override
        protected Class determineContextClass(ServletContext servletContext) throws ApplicationContextException {
            return ContextClassUtil.getVFSWebContextClass();

        }
    }
}

==> jboss-wfk-2.5.0-snowdrop-src.zip: jboss-wfk-2.5.0/src/snowdrop-3.1.0.Final-redhat-1/vfs/src/main/java/org/jboss/spring/vfs/context/DelegatingContextLoaderListener.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2011, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.spring.vfs.context;

import javax.servlet.ServletContext;

import org.springframework.context.ApplicationContextException;
import org.springframework.web.context.ContextLoader;
import org.springframework.web.context.ContextLoaderListener;

/**
 * @author Marius Bogoevici
 */
public class DelegatingContextLoaderListener extends ContextLoaderListener {

    @Override
    protected ContextLoader createContextLoader() {
        if (!ContextClassUtil.isJBossAS5orHigher()) {
            return super.createContextLoader();
        } else {
            return new VFSContextLoader();
        }
    }

    private static class VFSContextLoader extends ContextLoader {

        @Override
        protected Class<?> determineContextClass(ServletContext servletContext) throws ApplicationContextException {
            return ContextClassUtil.getVFSWebContextClass();

        }
    }
}
